==> planfacile_2.0.060802.orig.tar.gz: PlanFacile-2.0/src/analyseur/analyseur/analyseur.syn.h <==
/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOKEN_TEXTE = 258,
     TOKEN_STANDARD = 259,
     TOKEN_INCLUDE = 260,
     TOKEN_OPTION = 261,
     TOKEN_OPTIONS = 262,
     TOKEN_CASE = 263,
     TOKEN_OTHER = 264,
     TOKEN_END = 265,
     TOKEN_DEFINE = 266,
     TOKEN_PARAMETRE = 267,
     TOKEN_MACRO = 268,
     TOKEN_WARNING = 269,
     TOKEN_ERROR = 270,
     TOKEN_START = 271,
     TOKEN_HEAD = 272,
     TOKEN_FOOT = 273,
     TOKEN_SECTION = 274,
     TOKEN_REFERENCE = 275,
     TOKEN_MESSAGE = 276,
     TOKEN_TITLE = 277,
     TOKEN_REF = 278,
     TOKEN_TXT = 279,
     TOKEN_SEC = 280,
     TOKEN_MESG = 281,
     TOKEN_IDEA = 282,
     TOKEN_MISSING = 283,
     TOKEN_GENERIC = 284,
     TOKEN_TEXT = 285,
     TOKEN_INDEX = 286,
     TOKEN_EXTREF = 287,
     TOKEN_EXTREFS = 288,
     TOKEN_DEP = 289,
     TOKEN_DEPREF = 290,
     TOKEN_COMMENT = 291,
     TOKEN_PARAM_DEBUT = 292,
     TOKEN_PARAM_FIN = 293,
     TOKEN_ECHAP_COMMANDE = 294,
     TOKEN_ECHAP_PARAM_DEBUT = 295,
     TOKEN_ECHAP_PARAM_FIN = 296,
     TOKEN_ECHAP_RETOURLIGNE = 297,
     TOKEN_ECHAP_ESPACE = 298,
     TOKEN_ECHAP_TAB = 299
   };
#endif
#define TOKEN_TEXTE 258
#define TOKEN_STANDARD 259
#define TOKEN_INCLUDE 260
#define TOKEN_OPTION 261
#define TOKEN_OPTIONS 262
#define TOKEN_CASE 263
#define TOKEN_OTHER 264
#define TOKEN_END 265
#define TOKEN_DEFINE 266
#define TOKEN_PARAMETRE 267
#define TOKEN_MACRO 268
#define TOKEN_WARNING 269
#define TOKEN_ERROR 270
#define TOKEN_START 271
#define TOKEN_HEAD 272
#define TOKEN_FOOT 273
#define TOKEN_SECTION 274
#define TOKEN_REFERENCE 275
#define TOKEN_MESSAGE 276
#define TOKEN_TITLE 277
#define TOKEN_REF 278
#define TOKEN_TXT 279
#define TOKEN_SEC 280
#define TOKEN_MESG 281
#define TOKEN_IDEA 282
#define TOKEN_MISSING 283
#define TOKEN_GENERIC 284
#define TOKEN_TEXT 285
#define TOKEN_INDEX 286
#define TOKEN_EXTREF 287
#define TOKEN_EXTREFS 288
#define TOKEN_DEP 289
#define TOKEN_DEPREF 290
#define TOKEN_COMMENT 291
#define TOKEN_PARAM_DEBUT 292
#define TOKEN_PARAM_FIN 293
#define TOKEN_ECHAP_COMMANDE 294
#define TOKEN_ECHAP_PARAM_DEBUT 295
#define TOKEN_ECHAP_PARAM_FIN 296
#define TOKEN_ECHAP_RETOURLIGNE 297
#define TOKEN_ECHAP_ESPACE 298
#define TOKEN_ECHAP_TAB 299




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 129 "/home/jbruguier/planfacile/src/analyseur/analyseur/analyseur.syn.y"
typedef union YYSTYPE {	STOCKAGE_SCALAIRE(Chaine) _Chaine;
		STOCKAGE_SCALAIRE(Entier) _Entier;
		STOCKAGE(struct flux) _Flux;
		STOCKAGE(struct commande) _Commande;
		STOCKAGE(struct commandeoption) _CommandeOption;
		STOCKAGE(struct commandeoptions) _CommandeOptions;
		STOCKAGE(struct commandeoptionsclauses) _CommandeOptionsClauses;
		STOCKAGE(struct commandeoptionsclause) _CommandeOptionsClause;
		STOCKAGE(struct commandedefine) _CommandeDefine;
		STOCKAGE(struct commandewarning) _CommandeWarning;
		STOCKAGE(struct commandeerror) _CommandeError;
		STOCKAGE(struct commandestart) _CommandeStart;
		STOCKAGE(struct commandehead) _CommandeHead;
		STOCKAGE(struct commandefoot) _CommandeFoot;
		STOCKAGE(struct commandesection) _CommandeSection;
		STOCKAGE(struct commandereference) _CommandeReference;
		STOCKAGE(struct commandemessage) _CommandeMessage;
		STOCKAGE(struct commandetitle) _CommandeTitle;
		STOCKAGE(struct commanderef) _CommandeRef;
		STOCKAGE(struct commandetxt) _CommandeTxt;
		STOCKAGE(struct commandesec) _CommandeSec;
		STOCKAGE(struct commandemesg) _CommandeMesg;
		STOCKAGE(struct commandeidea) _CommandeIdea;
		STOCKAGE(struct commandemissing) _CommandeMissing;
		STOCKAGE(struct commandegeneric) _CommandeGeneric;
		STOCKAGE(struct commandeindex) _CommandeIndex;
		STOCKAGE(struct commandeextref) _CommandeExtRef;
		STOCKAGE(struct commandeextrefs) _CommandeExtRefs;
		STOCKAGE(struct commandedep) _CommandeDep;
		STOCKAGE(struct commandedepref) _CommandeDepRef;
		STOCKAGE(struct commandecommentaire) _CommandeCommentaire;
		STOCKAGE(struct commandeechappement) _CommandeEchappement;
		STOCKAGE(struct commandetexte) _CommandeTexte;
		STOCKAGE(struct commandemacro) _CommandeMacro;
		STOCKAGE(struct commandemacroparametres) _CommandeMacroParametres;
		STOCKAGE(struct commandeparametre) _CommandeParametre;
		STOCKAGE(struct commandeinclude) _CommandeInclude;
		STOCKAGE(struct commandestandard) _CommandeStandard;
	} YYSTYPE;
/* Line 1285 of yacc.c.  */
#line 165 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> planfacile_2.0.070523.orig.tar.gz: PlanFacile-2.0/src/analyseur/analyseur/analyseur.syn.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOKEN_TEXTE = 258,
     TOKEN_STANDARD = 259,
     TOKEN_INCLUDE = 260,
     TOKEN_OPTION = 261,
     TOKEN_OPTIONS = 262,
     TOKEN_CASE = 263,
     TOKEN_OTHER = 264,
     TOKEN_END = 265,
     TOKEN_DEFINE = 266,
     TOKEN_PARAMETRE = 267,
     TOKEN_MACRO = 268,
     TOKEN_WARNING = 269,
     TOKEN_ERROR = 270,
     TOKEN_START = 271,
     TOKEN_HEAD = 272,
     TOKEN_FOOT = 273,
     TOKEN_SECTION = 274,
     TOKEN_REFERENCE = 275,
     TOKEN_MESSAGE = 276,
     TOKEN_TITLE = 277,
     TOKEN_REF = 278,
     TOKEN_TXT = 279,
     TOKEN_SEC = 280,
     TOKEN_MESG = 281,
     TOKEN_IDEA = 282,
     TOKEN_MISSING = 283,
     TOKEN_GENERIC = 284,
     TOKEN_TEXT = 285,
     TOKEN_INDEX = 286,
     TOKEN_EXTREF = 287,
     TOKEN_EXTREFS = 288,
     TOKEN_DEP = 289,
     TOKEN_DEPREF = 290,
     TOKEN_COMMENT = 291,
     TOKEN_PARAM_DEBUT = 292,
     TOKEN_PARAM_FIN = 293,
     TOKEN_ECHAP_COMMANDE = 294,
     TOKEN_ECHAP_PARAM_DEBUT = 295,
     TOKEN_ECHAP_PARAM_FIN = 296,
     TOKEN_ECHAP_RETOURLIGNE = 297,
     TOKEN_ECHAP_ESPACE = 298,
     TOKEN_ECHAP_TAB = 299
   };
#endif
/* Tokens.  */
#define TOKEN_TEXTE 258
#define TOKEN_STANDARD 259
#define TOKEN_INCLUDE 260
#define TOKEN_OPTION 261
#define TOKEN_OPTIONS 262
#define TOKEN_CASE 263
#define TOKEN_OTHER 264
#define TOKEN_END 265
#define TOKEN_DEFINE 266
#define TOKEN_PARAMETRE 267
#define TOKEN_MACRO 268
#define TOKEN_WARNING 269
#define TOKEN_ERROR 270
#define TOKEN_START 271
#define TOKEN_HEAD 272
#define TOKEN_FOOT 273
#define TOKEN_SECTION 274
#define TOKEN_REFERENCE 275
#define TOKEN_MESSAGE 276
#define TOKEN_TITLE 277
#define TOKEN_REF 278
#define TOKEN_TXT 279
#define TOKEN_SEC 280
#define TOKEN_MESG 281
#define TOKEN_IDEA 282
#define TOKEN_MISSING 283
#define TOKEN_GENERIC 284
#define TOKEN_TEXT 285
#define TOKEN_INDEX 286
#define TOKEN_EXTREF 287
#define TOKEN_EXTREFS 288
#define TOKEN_DEP 289
#define TOKEN_DEPREF 290
#define TOKEN_COMMENT 291
#define TOKEN_PARAM_DEBUT 292
#define TOKEN_PARAM_FIN 293
#define TOKEN_ECHAP_COMMANDE 294
#define TOKEN_ECHAP_PARAM_DEBUT 295
#define TOKEN_ECHAP_PARAM_FIN 296
#define TOKEN_ECHAP_RETOURLIGNE 297
#define TOKEN_ECHAP_ESPACE 298
#define TOKEN_ECHAP_TAB 299




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 129 "/home/pappy/planfacile/planfacile/src/analyseur/analyseur/analyseur.syn.y"
{	STOCKAGE_SCALAIRE(Chaine) _Chaine;
		STOCKAGE_SCALAIRE(Entier) _Entier;
		STOCKAGE(struct flux) _Flux;
		STOCKAGE(struct commande) _Commande;
		STOCKAGE(struct commandeoption) _CommandeOption;
		STOCKAGE(struct commandeoptions) _CommandeOptions;
		STOCKAGE(struct commandeoptionsclauses) _CommandeOptionsClauses;
		STOCKAGE(struct commandeoptionsclause) _CommandeOptionsClause;
		STOCKAGE(struct commandedefine) _CommandeDefine;
		STOCKAGE(struct commandewarning) _CommandeWarning;
		STOCKAGE(struct commandeerror) _CommandeError;
		STOCKAGE(struct commandestart) _CommandeStart;
		STOCKAGE(struct commandehead) _CommandeHead;
		STOCKAGE(struct commandefoot) _CommandeFoot;
		STOCKAGE(struct commandesection) _CommandeSection;
		STOCKAGE(struct commandereference) _CommandeReference;
		STOCKAGE(struct commandemessage) _CommandeMessage;
		STOCKAGE(struct commandetitle) _CommandeTitle;
		STOCKAGE(struct commanderef) _CommandeRef;
		STOCKAGE(struct commandetxt) _CommandeTxt;
		STOCKAGE(struct commandesec) _CommandeSec;
		STOCKAGE(struct commandemesg) _CommandeMesg;
		STOCKAGE(struct commandeidea) _CommandeIdea;
		STOCKAGE(struct commandemissing) _CommandeMissing;
		STOCKAGE(struct commandegeneric) _CommandeGeneric;
		STOCKAGE(struct commandeindex) _CommandeIndex;
		STOCKAGE(struct commandeextref) _CommandeExtRef;
		STOCKAGE(struct commandeextrefs) _CommandeExtRefs;
		STOCKAGE(struct commandedep) _CommandeDep;
		STOCKAGE(struct commandedepref) _CommandeDepRef;
		STOCKAGE(struct commandecommentaire) _CommandeCommentaire;
		STOCKAGE(struct commandeechappement) _CommandeEchappement;
		STOCKAGE(struct commandetexte) _CommandeTexte;
		STOCKAGE(struct commandemacro) _CommandeMacro;
		STOCKAGE(struct commandemacroparametres) _CommandeMacroParametres;
		STOCKAGE(struct commandeparametre) _CommandeParametre;
		STOCKAGE(struct commandeinclude) _CommandeInclude;
		STOCKAGE(struct commandestandard) _CommandeStandard;
	}
/* Line 1489 of yacc.c.  */
#line 177 "analyseur.syn.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
